Session
=======

The HTTP(s) sessions are manged by a :class:`~icometrix_sdk.utils.api_client.ApiClient`. By default the
:class:`~icometrix_sdk.utils.request_api_client.RequestsApiClient` is used. But this can be modified to suite certain needs.

TODO
